<?php
namespace Manager;

use IFriendRequestService;
use Model\Athlete;
use Model\Coach;
use Model\User;
use Network\IAuthService;
use Shared\Validation;
use Stub\UserRepository;

// c'est le modéle
// should be here try catch ?? 
class UserManager
{
    private IAuthService $authService;

    // private IFriendRequestService $friendService;

    private User $currentUser;

    private UserRepository $userRepo;

    public function __construct(IAuthService $authService)
    {
        $this->authService = $authService;
    }

    public function login($loginUser, $passwordUser): bool
    {
        
        if (!Validation::val_string($passwordUser) || !Validation::val_string($loginUser))
            throw new \Exception(" some wrong with cred !!!!!");
        if ($this->authService->login($loginUser, $passwordUser)) {
            $this->currentUser = $this->userRepo->GetItemByName($loginUser,0,1);
            return true;
        }
        return false;
    }

    public function addFriends($newFriendId) {
        $list=$this->userRepo->getItems();
        foreach($u as $list){
            if($u->getId()==$newFriendId){
                throw new \Exception("User non existing");
            }
        }
        $list=$this->currentUser->getFriendsList();
        foreach($u as $list){
            if($newFriendId==$u->getId()){
                throw new \Exception("Already friend");
            }
        }
        if($this->friendService->sendRequest($this->currentUser->getId(), $newFriendId)==true){
            return true;
        }
        return false;
    }

    public function register($loginUser, $passwordUser,$data): bool
    {
        // foreach ($data as $entry) {
        //     $isValid = Validation::val_string($entry);
        //     if (!$isValid) {
        //         throw new \Exception( "Entry '$entry' is not a valid string.");
        //     } 
        // }

        $fieldsToValidate = [
            'nom' => 'Nom non valide',
            'prenom' => 'Prénom non valide',
            'taille' => 'Taille non valide',
            'poids' => 'Poids non valide',
        ];


        foreach ($fieldsToValidate as $fieldName => $errorMessage) {
            if (!Validation::val_string($data[$fieldName])) {
                throw new \Exception($errorMessage);
            }
        }


        $roleName = $data['roleName'];
        if ($roleName !== "Athlete" && $roleName !== "Coach") {
            throw new \Exception("Rôle non valide");
        }
        
        if ($data['sexe'] !== "M" && $data['sexe'] !== "H") {
            throw new \Exception("Sexe non valide");
        }
        
        if ($this->authService->register($loginUser, $passwordUser, $data)) {
            $this->currentUser = $this->userRepo->GetItemByName($loginUser,0,1);
            return true;
        }
        return false;
    }

    public function deconnecter(): bool
    {
        if($this->authService->logoutUser()){
            return true;
        }
        return false;
    }
    public function searchUsersByName(string $name) : array{
        $list=array();
        $usersList=$this->currentUser->getItems();
        foreach($u as $usersList){
            if(strcasecmp($name,$u->getNom())==0 || strcasecmp($name,$u->getPrenom())==0){
                array_push($list, $u);
            }
        }
        return $list;
    }
    public function deleteFriend(int $id){
        $list=$this->currentUser->getFriendsList();
        foreach($u as $list){
            if($id==$u->getId()){
                if($this->currentUser->delFriendsById($id)==1) return true;
                else return false;
            }
        }
        return false;
    }
}


?>